@@ -17,7 +17,6 @@ from sklearn.base import clone, is_classifier
 from sklearn.model_selection import check_cv
 from sklearn.model_selection._search import BaseSearchCV
 
-
 class ShapRFECV(BaseFitComputePlotClass):
     """
     This class performs Backwards Recursive Feature Elimination, using SHAP feature importance.
@@ -903,6 +902,7 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             verbose=verbose,
             random_state=random_state,
         )
+
         if self.search_clf:
             if self.verbose > 0:
                 warnings.warn(
@@ -921,6 +921,7 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             )
 
         self.eval_metric = eval_metric
+        
 
     def _get_feature_shap_values_per_fold(self, X, y, clf, train_index, val_index, sample_weight=None, **shap_kwargs):
         """
@@ -959,27 +960,33 @@ class EarlyStoppingShapRFECV(ShapRFECV):
             (np.array, float, float):
                 Tuple with the results: Shap Values on validation fold, train score, validation score.
         """
+        
+        # The lightgbm imports are temporarily placed here, until the tests on
+        # macOS have been fixed for lightgbm.
+        from lightgbm import early_stopping, LGBMModel
+        
         X_train, X_val = X.iloc[train_index, :], X.iloc[val_index, :]
         y_train, y_val = y.iloc[train_index], y.iloc[val_index]
 
-        if sample_weight is not None:
-            clf = clf.fit(
-                X_train,
-                y_train,
-                sample_weight=sample_weight.iloc[train_index],
-                eval_set=[(X_val, y_val)],
-                eval_sample_weight=[sample_weight.iloc[val_index]],
-                early_stopping_rounds=self.early_stopping_rounds,
-                eval_metric=self.eval_metric,
-            )
+        fit_params = {
+            'X':X_train,
+            'y':y_train,
+            'eval_set':[(X_val, y_val)],
+            'eval_metric':self.eval_metric
+        }
+
+        if isinstance(clf, LGBMModel):
+            fit_params['callbacks'] = [early_stopping(self.early_stopping_rounds)]
         else:
-            clf = clf.fit(
-                X_train,
-                y_train,
-                eval_set=[(X_val, y_val)],
-                early_stopping_rounds=self.early_stopping_rounds,
-                eval_metric=self.eval_metric,
-            )
+            fit_params['early_stopping_rounds'] = self.early_stopping_rounds
+
+        if sample_weight is not None:
+            fit_params['sample_weight'] = sample_weight.iloc[train_index]
+            fit_params['eval_sample_weight'] = [sample_weight.iloc[val_index]]
+
+        # Train the model
+        clf = clf.fit(**fit_params)
+
         # Score the model
         score_train = self.scorer.scorer(clf, X_train, y_train)
         score_val = self.scorer.scorer(clf, X_val, y_val)
